# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'
require_relative 'context_params_wrapper'

module AwsAccountStatus
  module Actions
    # This Action class does the work behind the "getAccountRegions" API query, fetching enabled
    # regions for a given account ID
    class GetEnabledRegions
      include ::Platform::Tasks::Actionable
      include Import['logger', 'statsd', 'data_access']

      # Gets the enabled regions for an Account
      def call
        request_start = ::Time.now.to_f * 1000.0
        id_param      = ContextParamsWrapper.new(context.params).entry_identifier
        logger.debug "GetEnabledRegions.call, id: #{id_param}"
        begin
          context.enabled_regions = data_access.get_enabled_regions(id_param)
        ensure
          # tag to allow us to identify metrics from canary deploy
          is_canary = ENV['K8S_POD']!=nil && ENV['K8S_POD'].include?("canary")
          tags = %W(
                  canary:#{is_canary}
          )
          statsd.increment 'get_enabled_regions.count', tags: tags
          request_end = ::Time.now.to_f * 1000.0
          elapsed     = request_end - request_start
          statsd.timing 'get_enabled_regions.duration', elapsed
        end
      end
    end
  end
end
