# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'

module AwsAccountStatus
  module Actions
    # This Action class does the work behind the "getSpendlessRegions" API query, fetching enabled
    # regions for a given account ID
    class GetSpendlessRegions
      include ::Platform::Tasks::Actionable
      include Import['logger','statsd','spend_data_access']

      # Gets the spendless regions for a given customer/account/service/asset
      def call
        request_start = ::Time.now.to_f * 1000.0
        customer_id   = context.params[:customer_id]
        account_id    = context.params[:account_id]
        service       = context.params[:service]
        asset         = context.params[:asset]
        logger.debug "GetSpendlessRegions.call, customer_id: #{customer_id}, account_id: #{account_id}, service: #{service}, asset: #{asset}"
        begin
          context.spendless_regions = spend_data_access.get_spendless_regions(customer_id, account_id, service, asset)

        ensure
          # tag to allow us to identify metrics from canary deploy
          is_canary = ENV['K8S_POD']!=nil && ENV['K8S_POD'].include?("canary")
          tags = %W(
                  canary:#{is_canary}
          )
          statsd.increment 'get_spendless_regions.count', tags: tags
          request_end = ::Time.now.to_f * 1000.0
          elapsed     = request_end - request_start
          statsd.timing 'get_spendless_regions.duration', elapsed
        end
      end
    end
  end
end
