# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'
require_relative 'context_params_wrapper'

module AwsAccountStatus
  module Actions
    # This Action class does the work behind the "getSupportedRegions" API query, fetching supported
    # regions for a given service
    class GetSupportedRegions
      include ::Platform::Tasks::Actionable
      include Import['logger', 'statsd', 'region_service_support_data_access']

      # Generic wrapper things for the resolver
      def call
        request_start = ::Time.now.to_f * 1000.0
        begin
          resolve
        ensure
          statsd.increment 'get_supported_regions.count'
          request_end = ::Time.now.to_f * 1000.0
          elapsed     = request_end - request_start
          statsd.timing 'get_supported_regions.duration', elapsed
        end
      end

      # Resolver for the query
      def resolve
        service = context.params[:service]
        logger.debug("Getting supported regions for service #{service}")

        context.supported_regions = region_service_support_data_access.get_supported_regions_by_service(service)

        # TODO: Do we need to catch redis error?
      end
    end
  end
end
