# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'

module AwsAccountStatus
  module Actions
    # This Action class does the work behind the "updateSpendlessRegions" API call.
    # It saves the whole request to the data layer, and audits that a change was made.
    class UpdateSpendlessRegions
      include ::Platform::Tasks::Actionable
      include Import['logger', 'statsd', 'spend_data_access']

      # Update the spendless regions for a customer/account/service/asset
      def call
        update_start  = ::Time.now.to_f * 1000.0
        input_params  = context.params[:input]
        customer_id   = input_params[:customer_id]
        account_id    = input_params[:account_id]
        service       = input_params[:service]
        asset         = input_params[:asset]
        input_regions = input_params[:regions]
        logger.debug "UpdateSpendlessRegions.call, customer_id: #{customer_id}, account_id: #{account_id}, service: #{service}, asset: #{asset}"
        begin
          spend_data_access.update_spendless_regions(customer_id, account_id, service, asset, input_regions)

        ensure
          statsd.increment 'update_spendless_regions'
          update_end = ::Time.now.to_f * 1000.0
          elapsed    = update_end - update_start
          logger.debug "UpdateSpendlessRegions.call, elapsed time: #{elapsed} msec"
          statsd.timing 'update_spendless_regions.duration', elapsed
          context['accountId'] = account_id
          context['customerId'] = customer_id
          context['updateResult'] = 'success'
        end
      end
    end
  end
end

