# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'
require_relative 'context_params_wrapper'

module AwsAccountStatus
  module Actions
    # This Action class does the work behind the "updateSupportedRegion" API call.
    #
    # It saves the supported services for a given region
    #
    class UpdateSupportedServices
      include ::Platform::Tasks::Actionable
      include Import['logger', 'statsd', 'region_service_support_data_access']

      # Update the enabled regions for an Account
      # See schema.graphql for input data definition
      def call
        update_start  = ::Time.now.to_f * 1000.0
        region_service_support  = deserialize_input(context.params[:input])
        begin
          region_service_support_data_access.update_supported_region_by_service(region_service_support)
        ensure
          statsd.increment 'update_supported_services.count'
          update_end = ::Time.now.to_f * 1000.0
          elapsed    = update_end - update_start
          logger.debug "UpdateAccountRegions.call, elapsed time: #{elapsed} msec"
          statsd.timing 'update_supported_services.duration', elapsed
        end
        context['updateResult'] = 'success'
      end

      def deserialize_input(mutation_input)
        region_service_support = AwsAccountStatus::Models::RegionServiceSupport.new(mutation_input[:region])

        mutation_input[:services].each do |service_input|
          region_service_support.add_service(name: service_input[:name], supported: service_input[:supported])
        end

        region_service_support
      end

    end
  end
end
