require 'import'
require 'cht-lib-fabric/graphql/client'
require 'hitimes'

module AwsAccountStatus
  module Clients
    class AuthorizationClient < ::Platform::GraphQL::Client
      include Import['logger', 'statsd']
      schema File.expand_path('../../../../config/schemas/authorization.json', __FILE__)
      queries File.expand_path('../authorization.graphql', __FILE__ )

      SERVICE_ACCOUNT_SUB = Set.new(["crn::service-account/cloudpercept"])

      def is_authorized(context: {})
        if is_service_account context
          logger.debug("Skipping Authorization.is_authorized API api for service_account")
          return true
        end

        logger.debug("Calling is_authorized API")

        result = false
        query_time = Hitimes::Interval.measure do
          result = query(Queries::IsAuthorized, context, {
            input: {
              subject: { crn: "crn::aws_account/*" },
              actions: ["read"],
              enforcement: "ALL"
            }
          })
        end

        tags = %W(success:#{result&.errors&.size == 0} query:is_authorized)
        logger.debug { "is_authorized API returned in #{query_time} seconds:" }
        statsd.histogram('authorization.time', query_time * 1000, tags: tags)

        result&.is_authorized.authorized
      end

      def is_service_account(context = {})
        return false if context[:request].nil? || context[:request].jwt_claims.nil?
        return true if SERVICE_ACCOUNT_SUB.include? context[:request].jwt_claims[:sub]

        false
      end
    end
  end
end
