require 'import'
require 'cht-lib-fabric/graphql/client'
require 'hitimes'

module AwsAccountStatus
  module Clients
    class IntegrationAwsClient < ::Platform::GraphQL::Client
      include Import['logger', 'statsd']
      schema File.expand_path('../../../../config/schemas/integration-aws.json', __FILE__)
      queries File.expand_path('../integration_aws.graphql', __FILE__ )

      def fetch_collection_status(customer_id:, account_crn:, context: {})
        logger.debug("Calling fetch_collection_status API: customer_id: #{customer_id} and account_crn: #{account_crn}")

        result = nil
        query_time = Hitimes::Interval.measure do
          result = query(Queries::CollectionStatus, context, {
            customer_id: customer_id,
            aws_account_id: 0, # ID needs to be 0 when sending a Crn
            aws_account_crn: account_crn
          })
        end

        tags = %W(success:#{result&.errors&.size == 0} query:collection_status)
        logger.debug { "fetch_collection_status API returned in #{query_time} seconds:" }
        statsd.histogram('integration_aws.time', query_time * 1000, tags: tags)

        result_hash = result&.collection_status.map { |r| r.to_h }
        deep_symbolize_hash_keys(result_hash)
      end

      def deep_symbolize_hash_keys(hash)
        JSON.parse(hash.to_json, :symbolize_names => true)
      end
    end
  end
end
