require 'import'
require 'cht-lib-fabric/graphql/client'
require 'hitimes'

module AwsAccountStatus
  module Clients
    class OrgManagementClient < ::Platform::GraphQL::Client
      include Import['logger', 'statsd']
      schema File.expand_path('../../../../config/schemas/org-management.json', __FILE__)
      queries File.expand_path('../org_management.graphql', __FILE__ )

      def fetch_accounts_in_org(org_crn:, context: {}, account_crns: [])

        page = 1
        end_cursor = nil
        accounts = []

        loop do
          logger.debug("Calling fetch_accounts_in_org API [org_crn: #{org_crn}, page: #{page}]")

          result = nil
          variables = { id: org_crn }
          variables[:endCursor] = end_cursor if end_cursor
          variables[:filters] = [build_filter('id', 'EQ', account_crns)] if account_crns.size > 0
          # variables[:first] = 1000 # probably need this if we see big loading times for VLC

          query_time = Hitimes::Interval.measure do
            result = query(Queries::AwsAccountsInOrg, context, variables)
          end

          tags = %W(success:#{result&.errors&.size == 0} query:aws_accounts_in_org)
          logger.debug { "fetch_accounts_in_org API returned in #{query_time} seconds" }
          statsd.histogram('org_management.time', query_time * 1000, tags: tags)

          accounts += result&.node&.aws_accounts&.edges&.map { |edge| edge&.node.to_h.transform_keys(&:to_sym) }

          # Keep going until we reach the last page of results.
          break unless result&.node&.aws_accounts&.page_info&.has_next_page

          end_cursor = result&.node&.aws_accounts&.page_info&.end_cursor
          page += 1
        end

        accounts
      end

      def fetch_accounts_in_org_page(org_crn:, context: {}, args: {})
        logger.debug("Calling fetch_accounts_in_org paginated API [org_crn: #{org_crn}")
        args[:id] = org_crn

        result = nil
        query_time = Hitimes::Interval.measure do
          result = query(Queries::AwsAccountsInOrgPage, context, args)
        end

        tags = %W(success:#{result&.errors&.size == 0} query:aws_accounts_in_org)
        logger.debug { "fetch_accounts_in_org API returned in #{query_time} seconds" }
        statsd.histogram('org_management.time', query_time * 1000, tags: tags)

        result&.node&.aws_accounts.to_h
      end

      private

      def build_filter(field, type, value)
        { 'field': field, 'filterType': type, 'filterValues': value }
      end
    end
  end
end
