# frozen_string_literal: true

require 'import'
require 'hitimes'

module AwsAccountStatus
  module Consumers
    class ApiStatusConsumer < ::Karafka::BaseConsumer
      include Import['logger', 'statsd', 'api_status_data_access']

      def consume
        duration_metric = Hitimes::TimedMetric.new 'Kafka Message Consumption'
        duration_metric.start
        begin
          api_status_data_access.upsert_access_statuses(params_batch)
        ensure
          duration_metric.stop
          record_metrics duration_metric
        end
      end

      private

      # Convert [Hitimes::TimedMetric] to ms
      # @param duration_metric[Hitimes::TimedMetric] Duration metric instance
      # @return [Integer] Duration in ms
      def get_duration_in_ms(duration_metric)
        (duration_metric.duration * 1000).to_i
      end

      # Record Metrics for consumption
      # @param duration_metric[Hitimes::TimedMetric] Duration metric instance
      # @return [Integer] Duration in ms
      def record_metrics(duration_metric)
        elapsed = get_duration_in_ms(duration_metric)
        statsd.increment 'upsert_access_statuses'
        logger.debug "UpsertAccessibleRegions.call, elapsed time: #{elapsed} msec"
        statsd.timing 'upsert_access_statuses.duration', elapsed
      end
    end
  end
end
