# frozen_string_literal: true

require 'graphql'
require 'cht-lib-fabric/helpers/wavefront'
require 'aws_account_status/actions'
require 'aws_account_status/helpers'

module AwsAccountStatus
  module GraphQL
    module Types
      class Query < ::Platform::GraphQL::Types::BaseObject
        include ::Platform::Helpers::GraphQL::RaiseError
        include Import["aws_account_api_access_status_resolver",
                       "aws_accounts_api_access_status_resolver",
                       "aws_api_access_status_overview_resolver"]

        # =============== getEnabledRegions ===============

        field :get_enabled_regions, [String], null: false do
          description "Get list of enabled regions for accountID"

          argument :account_id, String, required: true
          argument :customer_id, String, required: true
        end

        def get_enabled_regions(args)
          resolver = ::Platform::Helpers::GraphQL::ActionResolver.new(
            ::AwsAccountStatus::Actions::GetEnabledRegions, :enabled_regions
          )
          resolver.call(nil, args, context)
        end

        # =============== getSupportedRegions ===============

        field :get_supported_regions, [String], null: false do
          description "Get a list of Regions"

          argument :service, String, required: true
        end

        def get_supported_regions(args)
          resolver = ::Platform::Helpers::GraphQL::ActionResolver.new(
            ::AwsAccountStatus::Actions::GetSupportedRegions, :supported_regions
          )
          resolver.call(nil, args, context)
        end

        # =============== awsApiAccessStatusOverview ===============

        field :aws_api_access_status_overview, AwsApiAccessStatusOverview, null: false

        def aws_api_access_status_overview(**args)
          aws_api_access_status_overview_resolver.call(args, context)
        end

        # =============== awsAccountApiAccessStatus ===============

        field :aws_account_api_access_status, AwsAccountApiAccessStatus, null: false do
          argument :account_crn, String, required: true
        end

        def aws_account_api_access_status(**args)
          aws_account_api_access_status_resolver.call(args, context)
        end

        # =============== awsAccountsApiAccessStatus ===============
        field :aws_accounts_api_access_status, AwsAccountStatus::GraphQL::Types::AwsAccountsApiAccessStatusConnection, null: false,
              extensions: [FilterableExtension, SortableExtension], extras: [:lookahead]

        def aws_accounts_api_access_status(**args)
          _args = args[:lookahead].arguments

          # These args are stripped out from the top resolver and left to the connection but in our case, the top
          # level resolver will forward these to org-management since this query is gonna lean on their pagination
          args[:first] = _args[:first] if args[:first].nil? && !_args[:first].nil?
          args[:last] = _args[:last] if args[:last].nil? && !_args[:last].nil?
          args[:after] = _args[:after] if args[:after].nil? && !_args[:after].nil?
          args[:before] = _args[:before] if args[:before].nil? && !_args[:before].nil?

          aws_accounts_api_access_status_resolver.call(args, context)
        end

        # =============== GetSpendlessRegion ===============
        field :get_spendless_regions, resolver: Resolvers::GetSpendlessRegionsResolver
      end
    end
  end
end
