require 'hitimes'
require './app/aws_account_status/graph_ql/types/resolvers/base_api_access_resolver'

module AwsAccountStatus
  module GraphQL
    module Types
      module Resolvers
        class AwsAccountApiAccessStatusResolver < BaseApiAccessResolver

          def call(args, context)
            duration_metric = Hitimes::TimedMetric.new('aws_account_api_status_resolver')
            duration_metric.start
            begin
              resolve(args, context)
            ensure
              duration_metric.stop
              record_metrics duration_metric, 'aws_account_api_access_status'
            end
          end

          private

          def resolve(args, context)
            is_authorized?(context)

            customer_id = customer_id_from(context)
            organization_id = organization_id_from(context)
            account_crn = args[:account_crn]

            validate_org_scope(customer_id, organization_id, account_crn, context)

            builder = AwsAccountStatus::Helpers::ResponseBuilder::AwsAccountsWithApiAccessStatusResponseBuilder.new
            builder
              .api_statuses(get_api_status(customer_id, [account_crn]))
              .collection_status(get_collection_history(customer_id, account_crn))
              .spendless_regions(get_spendless_region(customer_id, account_crn))
              .build
          end

          def validate_org_scope(customer_id, organization_id, account_crn, context)
            organization_crn = build_organization_crn(customer_id, organization_id)
            accounts_in_scope = get_accounts_crns_in_org(organization_crn, context, account_crns: [account_crn])
            unless accounts_in_scope.include? account_crn
              raise ::Platform::GraphQL::Errors::ExecutionError,
                "Account is outside of organizational scope"
            end
          end
        end
      end
    end
  end
end
