require 'hitimes'
require './app/aws_account_status/graph_ql/types/resolvers/base_api_access_resolver'

module AwsAccountStatus
  module GraphQL
    module Types
      module Resolvers
        class AwsApiAccessStatusOverviewResolver < BaseApiAccessResolver

          def call(args, context)
            duration_metric = Hitimes::TimedMetric.new('aws_account_api_access_status_overview')
            duration_metric.start
            begin
              resolve(args, context)
            ensure
              duration_metric.stop
              record_metrics duration_metric, 'aws_account_api_access_status_overview'
            end
          end

          private

          def resolve(_, context)
            is_authorized?(context)

            customer_id = customer_id_from(context)
            organization_id = organization_id_from(context)
            organization_crn = build_organization_crn(customer_id, organization_id)
            accounts_in_scope = get_accounts_crns_in_org(organization_crn, context)

            logger.debug "Fetching inaccessible API Count from data-access for #{customer_id}"
            count = api_status_data_access.get_api_count_with_status(
              customer_id: customer_id,
              account_crns: accounts_in_scope,
              accessible: false
            )

            { inaccessible_api_count: count }
          end
        end
      end
    end
  end
end
