# frozen_string_literal: true

require 'graphql'

module AwsAccountStatus
  module GraphQL
    module Types
      class SortDirection < ::GraphQL::Schema::Enum
        value "ASC", "Ascending sort order"
        value "DESC", "Descending sort order"
      end

      class SortRule < ::GraphQL::Schema::InputObject
        # TODO: fields should be restricted to what is exposed in the original type
        argument :field, String, required: true, description: "Field on which to sort. Should be an attribute on the type being queried"
        argument :direction, SortDirection, required: false, default_value: "ASC", description: "Sort direction, ascending by default"
      end

      class SortableExtension < ::GraphQL::Schema::FieldExtension
        def apply
          field.argument :sort_rules, [SortRule], required: false, description: <<~EOD
            Rules for sorting search results.
            When multiple sort rules are provided, the first rule takes precendence
            and subsequent rules are used when the first rule does not provide a strict ordering.
          EOD
        end
      end
    end
  end
end
